import React, { useState } from "react";
import TextInput from "../form/TextInput";
import CheckBox from "../form/CheckBox";
import SliderInput from "../form/SliderInput";
import useLanguage from "../../hooks/useLanguage";
import { useSelector } from "react-redux";

function Filter({
  close,
  suppliers,
  handleSuppliersFilters,
  services,
  handleServiceFilters,
  priceRange,
  rangeHandler,
  setPriceRange,
  clearFilters,
}) {
  const [searchSupplier, setSearchSupplier] = useState();
  const handleSupplierSearch = (e) => {
    setSearchSupplier(e.target.value);
  };
  handleSupplierSearch.bind(this);

  const [searchService, setSearchService] = useState();
  const handleServiceSearch = (e) => {
    setSearchService(e.target.value);
  };
  handleServiceSearch.bind(this);
  const language = useLanguage();
  const sellerStatus = useSelector((state) => state.websiteSetup.sellerStatus);
  return (
    <div className="w-full max-w-full flex-col pt-5 pb-10  lg:px-[30px] px-3 bg-white rounded-md shadow-custom   absolute lg:static ">
      <div className="flex justify-between flex-row-reverse h-fit items-center ">
        <button
          onClick={() => {
            clearFilters();
          }}
          className=" text-primary-200 text-sm font-medium lg:block hidden "
        >
          <p className="notranslate">{language["Clear all filters"]}</p>
        </button>
        <button
          onClick={() => {
            close();
            clearFilters();
          }}
          className=" text-primary-200 text-sm font-medium lg:hidden"
        >
          <p className="notranslate">{language["Clear all filters"]}</p>
        </button>
        <h6 className=" text-dark-300 text-[22px] font-bold mb-[14px] notranslate">
          {sellerStatus ? language["Suppliers"] : language["Filter"]}
        </h6>
      </div>
      {!!sellerStatus ? (
        <>
          {" "}
          <TextInput
            placeholder="Search Suppliers"
            value={searchSupplier}
            handler={handleSupplierSearch}
          />
          <div className="pt-5">
            <div className="pb-4 flex flex-col gap-[22px] max-h-[370px] overflow-y-scroll filterScroll">
              {suppliers
                ?.filter((ser) =>
                  ser.shop_name
                    .toLowerCase()
                    .includes(
                      searchSupplier?.toLowerCase()
                        ? searchSupplier?.toLowerCase()
                        : ""
                    )
                )
                ?.map((supplier) => (
                  <CheckBox
                    key={"shop" + supplier?.id}
                    label={supplier?.shop_name}
                    id={"shop" + supplier?.id}
                    name={supplier?.id}
                    value={supplier?.active}
                    handler={handleSuppliersFilters}
                  />
                ))}
            </div>
            <hr className="bg-[#E8E8E8] mt-4" />
          </div>
        </>
      ) : (
        ""
      )}

      <SliderInput
        value={priceRange}
        min={1}
        max={9999}
        name="priceRange"
        handler={setPriceRange}
      />
      <div className="flex gap-5 mt-6">
        <TextInput
          id="min"
          name="0"
          value={priceRange[0]}
          handler={rangeHandler}
          placeholder="3200$"
          label="Set Min Price"
          type="number"
        />
        <TextInput
          id="max"
          name="1"
          value={priceRange[1]}
          handler={rangeHandler}
          placeholder="3200$"
          label="Set Max Price"
          type="number"
        />
      </div>
      <hr className="bg-[#E8E8E8] my-[30px]" />
      <h6 className=" text-dark-300 text-[22px] font-bold mb-[14px] notranslate">
        {language["SMC Service"]}
      </h6>
      <TextInput
        placeholder="Search Product..."
        value={searchService}
        handler={handleServiceSearch}
      />
      <div className="pt-5">
        <div className="pb-4 flex flex-col gap-[22px] max-h-[370px] overflow-y-scroll filterScroll">
          {services
            ?.filter((ser) =>
              ser.name
                .toLowerCase()
                .includes(
                  searchService?.toLowerCase()
                    ? searchService?.toLowerCase()
                    : ""
                )
            )
            ?.map((service) => (
              <CheckBox
                key={service?.id}
                label={service?.name}
                id={"service" + service?.id}
                name={service?.id}
                value={service?.active}
                handler={handleServiceFilters}
              />
            ))}
        </div>
        <hr className="bg-[#E8E8E8] mt-4" />
      </div>
      {/* <h6 className=" text-dark-300 text-[22px] font-bold mb-[14px] mt-10">
        Delivery Type
      </h6>
      <div className="pb-4 flex flex-col gap-[22px] ">
        <CheckBox label="Delivery" id="#" name="#" />
        <CheckBox label="Pickup" id="#" name="#" />
      </div> */}
      <button
        onClick={close}
        className=" text-primary-200 text-sm font-medium self-end lg:hidden secondaryBtn w-full "
      >
        <p className="w-full text-center notranslate">{language["Close"]}</p>
      </button>
    </div>
  );
}

export default Filter;
